************************************************************************
* TOTELA
* 
*   CALAULATION OF TOTAL, ELASTIC, NONELASTIC CROSS SECTIONS AND 
*   ELASTIC SCATTERING ANGULAR DISTRIBUTIONS FOR NEUTRON AND PROTON 
*   INCIDENTS
*
*   INPUT
*     NFILE: OUTPUT FILE NAME
*     IZ:    TARGET ATOMIC NUMBER
*     IA:    TARGET MASS NUMBER
*     NINC:  NEUTORON (1) OR PROTON (2) ID
*     IOPT:  SYSTEMATICS OPTION
*              IOPT=0 DEFAULT (1)
*              IOPT=1 NIITA
*              IOPT=2 PEARLSTEIN  
*     NE:    NUMBER OF INCIDENT ENERGIES
*              NE=0 DEFAULT (55)
*     NANG:  NUMBER OF ANGLES (ANGLE MESH)
*              NANG=0 DEFAULT (180)
*     EIN:   INCIDENT ENERGIES [MEV]
*
*   OUTPUT
*     ENDF-6 FORMAT FILE (UNIT 1)
************************************************************************
*
      PARAMETER  (ME1=200)
      PARAMETER  (NQ2=3)
      PARAMETER  (NQ3=10000)
*
      COMMON /CTAB1/  X(ME1),Y(ME1)
      COMMON /CTAB2/  NBT(NQ2),INTP(NQ2)
      COMMON /CLIST/  B(NQ3)
*
      CHARACTER  NFILE*80
      CHARACTER  BUN*66
      DIMENSION  E(55),EIN(ME1),XSEC(ME1,3)
      DIMENSION  ANG(ME1),DA(ME1)
      REAL*8     PNRG,ATARG,ANGLE,SIGS,DSIGS,ESCAT,ETARG,ANGCM
*
      DATA E/  20.0,  22.0,  24.0,  26.0,  28.0,
     &         30.0,  32.0,  34.0,  36.0,  38.0,
     &         40.0,  42.0,  44.0,  46.0,  48.0,
     &         50.0,  55.0,  60.0,  65.0,  70.0,
     &         80.0,  85.0,  90.0,  95.0, 100.0,
     &        110.0, 120.0, 130.0, 140.0, 150.0,
     &        160.0, 170.0, 180.0, 190.0, 200.0,
     &        220.0, 240.0, 260.0, 280.0, 300.0,
     &        320.0, 340.0, 360.0, 380.0, 400.0,
     &        450.0, 500.0, 550.0, 600.0, 700.0,
     &        800.0, 900.0,1000.0,2000.0,3000.0/
*
********** INITIALIZATION **********
*
      IOPTD=1
      NANGD=180
      NED=55
      INTP(2)=0
      INTP(3)=0
      NBT(2)=0
      NBT(3)=0
      PI=3.14159265
*
********** INPUT DATA **********
*
      WRITE(*,*) 'OUTPUT FILE NAME'
      READ(*,*)  NFILE
      WRITE(*,*) NFILE
      WRITE(*,*) 'TARGET Z,A AND NINC,IOPT,NE,NANG'
      READ(*,*)  IZ,IA,NINC,IOPT,NE,NANG
      WRITE(*,*) IZ,IA,NINC,IOPT,NE,NANG
*
      IF(NE.EQ.0) THEN
        NE=NED
        DO 100 I=1,NED
          EIN(I)=E(I)
  100   CONTINUE
      ELSE
        READ(*,*) (EIN(I),I=1,NE)
      ENDIF
      IF(NANG.EQ.0) NANG=NANGD
      IF(IOPT.EQ.0) IOPT=IOPTD
      IF(NINC.EQ.1) INCP=2
      IF(NINC.EQ.2) INCP=1
*
      OPEN(1,FILE=NFILE,STATUS='UNKNOWN')
*
*********** WRITE FILE 1 **********
*
      NS=0
      BUN='        '
      CALL TEXT(1,2,BUN,0,0,0,NS)
*
      MAT=IZ*100+IA-IA/100*100
      MF=1
      MT=451
      ZA=IZ*1000+IA
      AWR=IA
      LRP=-1
      LFI=0
      NLIB=0
      NMOD=1
      CALL CONT(1,2,ZA,AWR,LRP,LFI,NLIB,NMOD,MAT,MF,MT,NS)
*
      ELIS=0.0
      STA=0
      LIS=0
      LISO=0
      NFOR=6
      CALL CONT(1,2,ELIS,STA,LIS,LISO,0,NFOR,MAT,MF,MT,NS)
*
      AWI=1.0
      NSUB=10
      IF(NINC.EQ.2) NSUB=10010
      NVER=1
      CALL CONT(1,2,AWI,0.0,0,0,NSUB,NVER,MAT,MF,MT,NS)
*
      TEMP=0.0
      LDRV=0
      NWD=5
      NXC=0
      CALL CONT(1,2,TEMP,0.0,LDRV,0,NWD,NXC,MAT,MF,MT,NS)
*
      BUN='        '
      CALL TEXT(1,2,BUN,MAT,MF,MT,NS)
      BUN='TOTAL, ELASTIC, NONELASTIC CROSS SECTIONS AND'
      CALL TEXT(1,2,BUN,MAT,MF,MT,NS)
      BUN='ELASTIC SCATTERING ANGULAR DISTRIBUTIONS CALCULATED BY'
      CALL TEXT(1,2,BUN,MAT,MF,MT,NS)
      BUN='SYSTEMATICS OF NIITA'
      IF(IOPT.EQ.2) BUN='SYSTEMATICS OF PERLSTEIN' 
      CALL TEXT(1,2,BUN,MAT,MF,MT,NS)
      BUN='        '
      CALL TEXT(1,2,BUN,MAT,MF,MT,NS)
*
      CALL CONT(1,2,0.0,0.0,0,0,0,0,MAT,MF,0,NS)
      CALL CONT(1,2,0.0,0.0,0,0,0,0,MAT,0,0,NS)
*
*********** WRITE FILE 3 **********
*
      MF=3
*
*----- CALCULATING CROSS SECTIONS -----
*
      IF(IOPT.EQ.1) THEN
        DO 200 I=1,NE
          CALL SIGRC(INCP,EIN(I),IA,IZ,XSEC(I,1),XSEC(I,3),XSEC(I,2))
  200   CONTINUE
      ELSE
        DO 300 I=1,NE
          CALL TOTELA(EIN(I),IZ,IA,NINC,1,XSEC(I,1),XSEC(I,2),XSEC(I,3))
  300   CONTINUE
      ENDIF
*
*----- OUTPUT TOTAL CROSS SECTIONS -----
*
      IF(NINC.EQ.2) GO TO 10
      MT=1
*
      CALL CONT(1,2,ZA,AWR,0,0,0,0,MAT,MF,MT,NS)
*
      QM=0.0
      QI=0.0
      LR=0
      NR=1
      NP=NE
      NBT(1)=NE
      INTP(1)=2
      DO 400 I=1,NE
        X(I)=EIN(I)*1.0E+6
        Y(I)=XSEC(I,1)
  400 CONTINUE
      CALL TAB1(1,2,QM,QI,0,LR,NR,NP,MAT,MF,MT,NS)
*

      CALL CONT(1,2,0.0,0.0,0,0,0,0,MAT,MF,0,NS)
*
*----- OUTPUT ELASTIC CROSS SECTIONS -----
*
   10 CONTINUE
      MT=2
*
      CALL CONT(1,2,ZA,AWR,0,0,0,0,MAT,MF,MT,NS)
*
      QM=0.0
      QI=0.0
      LR=0
      NR=1
      NP=NE
      NBT(1)=NE
      INTP(1)=2
      DO 500 I=1,NE
        X(I)=EIN(I)*1.0E+6
        Y(I)=XSEC(I,2)
  500 CONTINUE
      CALL TAB1(1,2,QM,QI,0,LR,NR,NP,MAT,MF,MT,NS)
*
      CALL CONT(1,2,0.0,0.0,0,0,0,0,MAT,MF,0,NS)
*
*----- OUTPUT NONELASTIC CROSS SECTIONS -----
*
      MT=3
*
      CALL CONT(1,2,ZA,AWR,0,0,0,0,MAT,MF,MT,NS)
*
      DO 600 I=1,NE
        Y(I)=XSEC(I,3)
  600 CONTINUE
      CALL TAB1(1,2,QM,QI,0,LR,NR,NP,MAT,MF,MT,NS)
*
      CALL CONT(1,2,0.0,0.0,0,0,0,0,MAT,MF,0,NS)
      CALL CONT(1,2,0.0,0.0,0,0,0,0,MAT,0,0,NS)
*
*********** WRITE FILE 4 FOR NEUTRON AND 6 FOR PROTON **********
*-----------------------------------------------------------------------
*        S. Pearlstein, Nuc. Sci. Eng., 49, p.162-171(1972)
*        Hutcheon PRL 47,315(81) data 200-400 mev p+pb data
*        K. Niita
*
*        ICC =    0 -> Pearlstein
*                 1 -> Pearlstein + Hutcheon
*                 2 -> Niita
*-----------------------------------------------------------------------
*
      MF=4
      IF(NINC.EQ.2) MF=6
      MT=2
      ICC=2
      IF(IOPT.EQ.2) ICC=1
      ICM=0
      LCT=2
      DANG=180.0/FLOAT(NANG)
      DARAD=DANG*PI/180.0
      DO 700 J=1,NANG+1
        ANG(J)=DANG*FLOAT(J-1)
  700 CONTINUE
*
*----- OUTPUT HEAD RECORDS -----
*
      GO TO (20,30),NINC
*
*  NEUTRON
*
   20 CONTINUE
*
      LTT=2
      LVT=0
      LI=0
      CALL CONT(1,2,ZA,AWR,LVT,LTT,0,0,MAT,MF,MT,NS)
*
      LI=0
      CALL CONT(1,2,0.0,AWR,LI,LCT,0,0,MAT,MF,MT,NS)
*
      NBT(1)=NE
      INTP(1)=2
      CALL TAB2(1,2,0.0,0.0,0,0,NR,NE,MAT,MF,MT,NS)
*
      GO TO 40
*
*  PROTON
*
   30 CONTINUE
*
      NK=1
      CALL CONT(1,2,ZA,AWR,0,LCT,NK,0,MAT,MF,MT,NS)
*
      ZAP=1001.0
      AWP=0.99862
      LIP=0
      LAW=5
      NP=2
      NBT(1)=2
      INTP(1)=2
      X(1)=EIN(1)*1.0E+6
      X(2)=EIN(NE)*1.0E+6
      Y(1)=1.0
      Y(2)=1.0
      CALL TAB1(1,2,ZAP,AWP,LIP,LAW,NR,NP,MAT,MF,MT,NS)
*
      SPI=0.5
      LIDP=0
      NBT(1)=NE
      INTP(1)=2
      CALL TAB2(1,2,SPI,0.0,LIDP,0,NR,NE,MAT,MF,MT,NS)
*
   40 CONTINUE
*
      DO 800 I=1,NE
*
*----- CALCULATING ELASTIC SCATTERING ANGULAR DISTRIBUTIONS -----
*
      SUM=0.0
      DO 900 J=1,NANG+1
        PNRG=EIN(I)
        ATARG=DFLOAT(IA)
        ANGLE=ANG(J)
        SIGS=XSEC(I,3)
        CALL DSDARC(ICC,ICM,INCP,PNRG,ATARG,ANGLE,SIGS,
     &              DSIGS,ESCAT,ETARG,ANGCM)
        DA(J)=DSIGS
        FACT=1.0
        IF(J.EQ.1.OR.J.EQ.NANG+1) FACT=0.5
        SUM=SUM+DA(J)*2.0*PI*SIN(ANG(J)*PI/180.0)*DARAD*FACT
  900 CONTINUE
*
*----- OUTPUT ELASTIC SCATTERING ANGULAR DISTRIBUTIONS -----
*
      GO TO (50,60),NINC
*
*  NEUTRON
*
   50 CONTINUE
*
      T=0.0
      EE=EIN(I)*1.0E+6
      LT=0
      NP=NANG+1
      NBT(1)=NP
      INTP(1)=2
      DO 1000 J=1,NANG+1
        X(J)=COS(ANG(NANG+2-J)*PI/180.0)
        Y(J)=DA(NANG+2-J)/SUM*2.0*PI
 1000 CONTINUE
      CALL TAB1(1,2,T,EE,LT,0,NR,NP,MAT,MF,MT,NS)
*
      GO TO 800
*
*  PROTON
*
   60 CONTINUE
*
      EE=EIN(I)*1.0E+6
      LTP=12
      NL=NANG+1
      NW=NL*2
      DO 1100 J=1,NANG+1
        B(J*2-1)=COS(ANG(NANG+2-J)*PI/180.0)
        B(J*2  )=DA(NANG+2-J)/SUM*2.0*PI
 1100 CONTINUE
      CALL LIST(1,2,0.0,EE,LTP,0,NW,NL,MAT,MF,MT,NS)
*
  800 CONTINUE
*
      CALL CONT(1,2,0.0,0.0,0,0,0,0,MAT,MF,0,NS)
      CALL CONT(1,2,0.0,0.0,0,0,0,0,MAT,0,0,NS)
*
*********** WRITE END RECORD **********
*
      CALL CONT(1,2,0.0,0.0,0,0,0,0,0,0,0,NS)
      CALL CONT(1,2,0.0,0.0,0,0,0,0,-1,0,0,NS)
*
*********** END **********
*
      CLOSE(1)
      STOP
      END
